@@ -1,11 +1,12 @@
-#!/usr/bin/python
+#!/usr/bin/python3.10
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.gdal_pansharpen as a convenience to use as a script
 from osgeo_utils.gdal_pansharpen import *  # noqa
 from osgeo_utils.gdal_pansharpen import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('gdal_pansharpen')
+deprecation_warn("gdal_pansharpen")
 sys.exit(main(sys.argv))
